fnss.topologies.datacenter.DatacenterTopology.applications — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.topologies.datacenter.DatacenterTopology.applications

`DatacenterTopology.` `applications`()

  Return a dictionary of all applications deployed, keyed by node

  Returns : | applications : dict A dictionary of all applications deployed, keyed by node.

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »